#rules for scc8080, ASX, asm80 .asm and m4 preprocessed .Asm
#$Id: m100rules.mk,v 1.3 2017/05/12 06:59:26 goosey Exp goosey $

#do not delete hex files just because they're intermediates
.PRECIOUS: %.hex

#default address to link to
DEF_ADDRESS=0xF000

%.hex: %.asm
	asm80 -l $<
#-l=create lst file
#asm80 prints topmost address when finished
	@echo MAXRAM = F5EF
	todos < $@ > $@.dos
	rm $@
	mv $@.dos $@

%.asm: %.Asm
	m4 ${M4OPTS} $< > $@	

%.hex: %.zm
	zmac -h -z -m $<
#-h = hex file output
#-z = no z80 only instructions
#-m = expand macros in lst file
	todos < $@ > $@.dos
	rm $@
	mv $@.dos $@

%.s: %.c
	scc8080 -u $<

%.rel: %.a85
	as8085 -l -g -o $@ $<

#scc8080 outputs file.s
%.rel: %.s
	as8085 -g -o $@ $<

#-l = lst file
#-g = don't complain about unknown globals
#-o = enable output

%.ihx: %.rel
	aslink -n -i -m -b M100_CODE=${DEF_ADDRESS} -o $@ lib/cstart.rel $^ -l small.lib
#-n = no echo commands to stdout
#-u = update lst file to rst file
#-i = hex file out
#-m = generate map file
#-b modname=address module modname starts at address
#-l library library file
#-o = output file

#force hex file to be continous and in order for hex2co
%.hex: %.ihx
	objcopy -I ihex -O ihex --gap-fill 0 $< $@

%.co: %.hex
	hex2co $<

#REX rom image
%.bx: %.hex
	objcopy -I ihex -O binary --pad-to 32768 $< $@ 
